/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as c, createVNode as e } from "vue";
import { packageMetadata as a } from "./package-metadata.mjs";
import { exclamationCircleIcon as s, infoCircleIcon as r, xOutlineIcon as l, checkOutlineIcon as u, xIcon as d } from "@progress/kendo-svg-icons";
import { validatePackage as p, guid as m, getDefaultSlots as f, Icon as i } from "@progress/kendo-vue-common";
const h = "Close", C = /* @__PURE__ */ c({
  name: "KendoNotification",
  props: {
    closable: {
      type: [Object, Boolean],
      default: function() {
        return !1;
      }
    },
    dir: String,
    type: {
      type: Object,
      default: function() {
        return {
          style: "none",
          icon: !0
        };
      },
      validator: function(t) {
        return ["none", "success", "error", "warning", "info"].includes(t.style);
      }
    },
    themeColor: {
      type: String,
      default: "base",
      validator: function(t) {
        return [null, "base", "error", "info", "success", "warning"].includes(t);
      }
    },
    ariaLabel: {
      type: String,
      default: void 0
    }
  },
  created() {
    p(a), this.notificationContentId = m();
  },
  computed: {
    computedTheme() {
      const {
        type: t,
        themeColor: n
      } = this.$props;
      return t.style !== "none" ? t.style : n;
    },
    computedSvg() {
      switch (this.computedTheme) {
        case "success":
          return {
            name: "check-outline",
            icon: u
          };
        case "error":
          return {
            name: "x-outline",
            icon: l
          };
        case "info":
          return {
            name: "info-circle",
            icon: r
          };
        case "warning":
          return {
            name: "exclamation-circle",
            icon: s
          };
        default:
          return {};
      }
    },
    wrapperClass() {
      const {
        closable: t
      } = this.$props;
      return {
        "k-notification": !0,
        [`k-notification-${this.computedTheme}`]: this.computedTheme,
        "k-notification-closable": t
      };
    }
  },
  render() {
    const t = f(this), {
      closable: n,
      type: o
    } = this.$props;
    return e("div", {
      role: "alert",
      class: this.wrapperClass,
      style: this.$props.style,
      "aria-live": "polite",
      "aria-label": this.$props.ariaLabel,
      "aria-describedby": this.notificationContentId
    }, [o.icon && this.computedSvg.name && e(i, {
      name: this.computedSvg.name,
      icon: this.computedSvg.icon,
      class: "k-notification-status"
    }, null), e("div", {
      class: "k-notification-content",
      id: this.notificationContentId
    }, [t]), n && e("span", {
      class: "k-notification-actions"
    }, [e("span", {
      class: "k-notification-action k-notification-close-action",
      "aria-hidden": !0
    }, [e(i, {
      name: "x",
      icon: d,
      title: h,
      onClick: this.handleClick
    }, null)])])]);
  },
  methods: {
    handleClick(t) {
      this.$emit("close", {
        component: this,
        event: t
      });
    }
  }
});
export {
  C as Notification
};
