/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { ComponentOptionsMixin } from 'vue';
import { ComponentProvideOptions } from 'vue';
import { DefineComponent } from 'vue';
import { ExtractPropTypes } from 'vue';
import { PropType } from 'vue';
import { PublicProps } from 'vue';
import { SVGIcon } from '@progress/kendo-svg-icons';

/**
 * Represents the [Kendo UI for Vue Native Notification component]({% slug overview_notification %}).
 *
 *
 * ### props <span class='code'>Readonly&lt;[NotificationProps]({% slug api_notification_notificationprops %})</span>
 * The props of the Notification component.
 *
 */
declare const Notification_2: DefineComponent<ExtractPropTypes<    {
closable: {
type: PropType<any>;
default: () => boolean;
};
dir: PropType<string>;
type: {
type: PropType<{
style?: 'none' | 'success' | 'error' | 'warning' | 'info';
icon?: boolean;
}>;
default: () => {
style: string;
icon: boolean;
};
validator: (value: any) => any;
};
themeColor: {
type: PropType<string>;
default: string;
validator: (value: any) => any;
};
ariaLabel: {
type: PropType<string>;
default: any;
};
}>, {}, {}, {
computedTheme(): any;
computedSvg(): {
name: string;
icon: SVGIcon;
} | {
name?: undefined;
icon?: undefined;
};
wrapperClass(): {
[x: string]: any;
'k-notification': boolean;
'k-notification-closable': any;
};
}, {
handleClick(event: any): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly<ExtractPropTypes<    {
closable: {
type: PropType<any>;
default: () => boolean;
};
dir: PropType<string>;
type: {
type: PropType<{
style?: 'none' | 'success' | 'error' | 'warning' | 'info';
icon?: boolean;
}>;
default: () => {
style: string;
icon: boolean;
};
validator: (value: any) => any;
};
themeColor: {
type: PropType<string>;
default: string;
validator: (value: any) => any;
};
ariaLabel: {
type: PropType<string>;
default: any;
};
}>> & Readonly<{}>, {
type: {
style?: 'none' | 'success' | 'error' | 'warning' | 'info';
icon?: boolean;
};
ariaLabel: string;
themeColor: string;
closable: any;
}, {}, {}, {}, string, ComponentProvideOptions, true, {}, any>;
export { Notification_2 as Notification }

/**
 * The `close` event object of the Notification.
 */
export declare interface NotificationEvent {
    /**
     * A native DOM event.
     */
    event: Event;
    /**
     * An event target.
     */
    target: Notification;
}

/**
 * Represents the [Kendo UI for Vue NotificationGroup component]({% slug positioning_notification %}) that can set the position of the Notification component.
 */
export declare const NotificationGroup: DefineComponent<ExtractPropTypes<    {
style: PropType<object>;
className: PropType<string>;
}>, {}, {}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly<ExtractPropTypes<    {
style: PropType<object>;
className: PropType<string>;
}>> & Readonly<{}>, {}, {}, {}, {}, string, ComponentProvideOptions, true, {}, any>;

/**
 * Represents the props of the [Kendo UI for Vue Notification component]({% slug overview_notification %}).
 */
export declare interface NotificationProps {
    /**
     * Specifies if the Notification will require a user action to hide.
     * If the property is set to `true`, the Notification renders a **Close** button.
     * If the property is set to `object`, the Notification renders a **Close** button
     * by extending the default props with the provided object.
     *
     * The possible values are:
     * * (Default) `false`
     * * `true`
     * * `{ title: 'Hide', ... }`
     */
    closable?: boolean | any;
    /**
     * The `dir` HTML attribute.
     */
    dir?: string;
    /**
     * The Notification type
     * ([see example]({% slug types_notification %})).
     *
     * The possible values are:
     * * `style: 'none'|'success'|'error'|'warning'|'info'`. Defaults to `none`.
     * * `icon?: 'true'|'false'`. Defaults to `true`.
     */
    type?: {
        style?: 'none' | 'success' | 'error' | 'warning' | 'info';
        icon?: boolean;
    };
    /**
     * Configures the `themeColor` of the Notification.
     */
    themeColor?: string;
    /**
     * The `close` event which will be triggered when the **Close** button is clicked.
     */
    onClose?: (event: NotificationEvent) => void;
    /**
     * Defines the aria-label attribute of the Notification component. Defaults to `undefined`.
     */
    ariaLabel?: string;
}

export { }
